@@ -16,6 +16,7 @@ import os
 import sys
 
 # Local import
+from spyder.plugins.toolbar.api import ApplicationToolbars
 from spyder.config.base import CHECK_ALL, EXCLUDED_NAMES
 from spyder.config.utils import IMPORT_EXT
 from spyder.config.appearance import APPEARANCE
@@ -93,7 +94,14 @@ DEFAULTS = [
              {
               'enable': True,
               'toolbars_visible': True,
-              'last_visible_toolbars': [],
+              'last_visible_toolbars': [
+                  ApplicationToolbars.File,
+                  ApplicationToolbars.Run,
+                  ApplicationToolbars.Debug,
+                  ApplicationToolbars.Main,
+                  ApplicationToolbars.WorkingDirectory,
+              ],
+              'last_toolbars': [],
              }),
             ('statusbar',
              {
@@ -320,7 +328,8 @@ DEFAULTS = [
               'show_hidden': True,
               'size_column': False,
               'type_column': False,
-              'date_column': False
+              'date_column': False,
+              'search_files_in_switcher': True,
               }),
             ('explorer',
              {
@@ -514,8 +523,8 @@ DEFAULTS = [
               # -- Profiler --
               'profiler/run file in profiler': "F10",
               # -- Switcher --
-              'switcher/file switcher': 'Ctrl+P',
-              'switcher/symbol finder': 'Ctrl+Alt+P',
+              '_/file switcher': 'Ctrl+P',
+              '_/symbol finder': 'Ctrl+Alt+P',
               # -- IPython console --
               'ipython_console/new tab': "Ctrl+T",
               'ipython_console/reset namespace': "Ctrl+Alt+R",
@@ -530,14 +539,14 @@ DEFAULTS = [
               'variable_explorer/search': 'Ctrl+F',
               'variable_explorer/refresh': 'Ctrl+R',
               # -- Debugger --
+              '_/run file in debugger': "Ctrl+F5",
+              '_/debug current line': "Ctrl+F10",
+              '_/debug continue': "Ctrl+F12",
+              '_/debug step into': "Ctrl+F11",
+              '_/debug step return': "Ctrl+Shift+F11",
+              '_/debug stop': "Ctrl+Shift+F12",
               'debugger/refresh': 'Ctrl+R',
               'debugger/search': 'Ctrl+F',
-              'debugger/run file in debugger': "Ctrl+F5",
-              'debugger/next': "Ctrl+F10",
-              'debugger/continue': "Ctrl+F12",
-              'debugger/step': "Ctrl+F11",
-              'debugger/return': "Ctrl+Shift+F11",
-              'debugger/stop': "Ctrl+Shift+F12",
               'debugger/toggle breakpoint': 'F12',
               'debugger/toggle conditional breakpoint': 'Shift+F12',
               'debugger/show breakpoint table': "",
@@ -587,10 +596,6 @@ NAME_MAP = {
             'window/state',
             ]
          ),
-        ('toolbar', [
-            'last_visible_toolbars',
-            ]
-         ),
         ('editor', [
             'autosave_mapping',
             'bookmarks',
@@ -645,8 +650,10 @@ NAME_MAP = {
             'breakpoints',
             'configurations',
             'default/wdir/fixed_directory',
-            'last_used_parameters',
-            'parameters'
+            'parameters',
+            'last_used_parameters', # Needed for Spyder 6.0.0 to 6.0.3
+            'last_used_parameters_per_executor',
+            'last_configured_executor',
           ]
          ),
         ('workingdir', [
@@ -672,4 +679,4 @@ NAME_MAP = {
 #    or if you want to *rename* options, then you need to do a MAJOR update in
 #    version, e.g. from 3.0.0 to 4.0.0
 # 3. You don't need to touch this value if you're just adding a new option
-CONF_VERSION = '84.2.0'
+CONF_VERSION = '86.0.0'
