@@ -12,7 +12,7 @@ import os.path as osp
 import sys
 
 # Local imports
-from spyder.config.base import _, is_pynsist, running_in_ci, running_in_mac_app
+from spyder.config.base import _, running_in_ci, is_conda_based_app
 from spyder.utils import programs
 
 
@@ -34,15 +34,17 @@ PLUGIN = 'spyder plugins'
 # Versions
 # =============================================================================
 # Hard dependencies
+AIOHTTP_REQVER = '>=3.9.3'
 APPLAUNCHSERVICES_REQVER = '>=0.3.0'
+ASYNCSSH_REQVER = '>=2.14.0,<3.0.0'
 ATOMICWRITES_REQVER = '>=1.2.0'
+BCRYPT_REQVER = ">=4.3.0"
 CHARDET_REQVER = '>=2.0.0'
 CLOUDPICKLE_REQVER = '>=0.5.0'
 COOKIECUTTER_REQVER = '>=1.6.0'
 DIFF_MATCH_PATCH_REQVER = '>=20181111'
-# None for pynsist install for now
-# (check way to add dist.info/egg.info from packages without wheels available)
-INTERVALTREE_REQVER = None if is_pynsist() else '>=3.0.2'
+IMPORTLIB_METADATA_REQVER = '>=4.6.0'
+INTERVALTREE_REQVER = '>=3.0.2'
 IPYTHON_REQVER = ">=8.12.2,<8.13.0" if PY38 else ">=8.13.0,<9.0.0,!=8.17.1"
 JEDI_REQVER = '>=0.17.2,<0.20.0'
 JELLYFISH_REQVER = '>=0.7'
@@ -50,34 +52,34 @@ JSONSCHEMA_REQVER = '>=3.2.0'
 KEYRING_REQVER = '>=17.0.0'
 NBCONVERT_REQVER = '>=4.0'
 NUMPYDOC_REQVER = '>=0.6.0'
-PARAMIKO_REQVER = '>=2.4.0'
+PACKAGING_REQVER = '>=20.0'
 PARSO_REQVER = '>=0.7.0,<0.9.0'
 PEXPECT_REQVER = '>=4.4.0'
 PICKLESHARE_REQVER = '>=0.4'
 PSUTIL_REQVER = '>=5.3'
+PYGITHUB_REQVER = '>=2.3.0'
 PYGMENTS_REQVER = '>=2.0'
-PYLINT_REQVER = '>=2.5.0,<3.1'
+PYLINT_REQVER = '>=3.1,<4'
 PYLINT_VENV_REQVER = '>=3.0.2'
-PYLSP_REQVER = '>=1.10.0,<1.11.0'
+PYLSP_REQVER = '>=1.12.0,<1.13.0'
 PYLSP_BLACK_REQVER = '>=2.0.0,<3.0.0'
 PYLS_SPYDER_REQVER = '>=0.4.0'
+PYUCA_REQVER = '>=1.2'
 PYXDG_REQVER = '>=0.26'
 PYZMQ_REQVER = '>=24.0.0'
 QDARKSTYLE_REQVER = '>=3.2.0,<3.3.0'
 QSTYLIZER_REQVER = '>=0.2.2'
-QTAWESOME_REQVER = '>=1.2.1,<1.3.0'
-QTCONSOLE_REQVER = '>=5.5.1,<5.6.0'
-QTPY_REQVER = '>=2.1.0'
+QTAWESOME_REQVER = '>=1.4.0,<1.5.0'
+QTCONSOLE_REQVER = '>=5.6.1,<5.7.0'
+QTPY_REQVER = '>=2.4.0'
 RTREE_REQVER = '>=0.9.7'
-SETUPTOOLS_REQVER = '>=49.6.0'
 SPHINX_REQVER = '>=0.6.6'
-SPYDER_KERNELS_REQVER = '>=2.5.1,<2.6.0'
+SPYDER_KERNELS_REQVER = '>=3.0.4,<3.1.0'
+SUPERQT_REQVER = '>=0.6.2,<1.0.0'
 TEXTDISTANCE_REQVER = '>=4.2.0'
 THREE_MERGE_REQVER = '>=0.1.1'
-# None for pynsist install for now
-# (check way to add dist.info/egg.info from packages without wheels available)
-WATCHDOG_REQVER = None if is_pynsist() else '>=0.10.3'
-
+WATCHDOG_REQVER = '>=0.10.3'
+YARL_REQVER = '>=1.9.4'
 
 # Optional dependencies
 CYTHON_REQVER = '>=0.21'
@@ -96,15 +98,27 @@ SYMPY_REQVER = '>=0.7.3'
 # =============================================================================
 # List of descriptions
 DESCRIPTIONS = [
+    {'modname': 'aiohttp',
+     'package_name': 'aiohttp',
+     'features': _('Async http client/server'),
+     'required_version': AIOHTTP_REQVER},
     {'modname': "applaunchservices",
      'package_name': "applaunchservices",
      'features': _("Notify macOS that Spyder can open Python files"),
      'required_version': APPLAUNCHSERVICES_REQVER,
-     'display': sys.platform == "darwin" and not running_in_mac_app()},
+     'display': sys.platform == "darwin" and not is_conda_based_app()},
+    {'modname': 'asyncssh',
+     'package_name': 'asyncssh',
+     'features': _('Connect to remote kernels through SSH'),
+     'required_version': ASYNCSSH_REQVER},
     {'modname': "atomicwrites",
      'package_name': "atomicwrites",
      'features': _("Atomic file writes in the Editor"),
      'required_version': ATOMICWRITES_REQVER},
+    {'modname': "bcrypt",
+     'package_name': "bcrypt",
+     'features': _("Decrypt passphrase of SSH key files"),
+     'required_version': BCRYPT_REQVER},
     {'modname': "chardet",
      'package_name': "chardet",
      'features': _("Character encoding auto-detection for the Editor"),
@@ -121,6 +135,10 @@ DESCRIPTIONS = [
      'package_name': "diff-match-patch",
      'features': _("Compute text file diff changes during edition"),
      'required_version': DIFF_MATCH_PATCH_REQVER},
+    {'modname': 'importlib_metadata',
+     'package_name': 'importlib-metadata',
+     'features': _('Access the metadata for a Python package'),
+     'required_version': IMPORTLIB_METADATA_REQVER},
     {'modname': "intervaltree",
      'package_name': "intervaltree",
      'features': _("Compute folding range nesting levels"),
@@ -154,11 +172,10 @@ DESCRIPTIONS = [
      'package_name': "numpydoc",
      'features': _("Improve code completion for objects that use Numpy docstrings"),
      'required_version': NUMPYDOC_REQVER},
-    {'modname': "paramiko",
-     'package_name': "paramiko",
-     'features': _("Connect to remote kernels through SSH"),
-     'required_version': PARAMIKO_REQVER,
-     'display': os.name == 'nt'},
+    {'modname': "packaging",
+     'package_name': "packaging",
+     'features': _("Compare version numbers of Python packages"),
+     'required_version': PACKAGING_REQVER},
     {'modname': "parso",
      'package_name': "parso",
      'features': _("Python parser that supports error recovery and "
@@ -176,6 +193,10 @@ DESCRIPTIONS = [
      'package_name': "psutil",
      'features': _("CPU and memory usage info in the status bar"),
      'required_version': PSUTIL_REQVER},
+    {'modname': "github",
+     'package_name': "pygithub",
+     'features': _("Python API for Github REST API"),
+     'required_version': PYGITHUB_REQVER},
     {'modname': "pygments",
      'package_name': "pygments",
      'features': _("Syntax highlighting for a lot of file types in the Editor"),
@@ -202,6 +223,10 @@ DESCRIPTIONS = [
      'package_name': 'pyls-spyder',
      'features': _('Spyder plugin for the Python LSP Server'),
      'required_version': PYLS_SPYDER_REQVER},
+    {'modname': 'pyuca',
+     'package_name': 'pyuca',
+     'features': _('Properly sort lists of non-English strings'),
+     'required_version': PYUCA_REQVER},
     {'modname': "xdg",
      'package_name': "pyxdg",
      'features': _("Parse desktop files on Linux"),
@@ -233,12 +258,8 @@ DESCRIPTIONS = [
      'required_version': QTPY_REQVER},
     {'modname': "rtree",
      'package_name': "rtree",
-     'features': _("Fast access to code snippets regions"),
+     'features': _("Fast access to code snippet regions"),
      'required_version': RTREE_REQVER},
-    {'modname': "setuptools",
-     'package_name': "setuptools",
-     'features': _("Determine package version"),
-     'required_version': SETUPTOOLS_REQVER},
     {'modname': "sphinx",
      'package_name': "sphinx",
      'features': _("Show help for objects in the Editor and Consoles in a dedicated pane"),
@@ -247,6 +268,10 @@ DESCRIPTIONS = [
      'package_name': "spyder-kernels",
      'features': _("Jupyter kernels for the Spyder console"),
      'required_version': SPYDER_KERNELS_REQVER},
+     {'modname': "superqt",
+     'package_name': "superqt",
+     'features': _("Special widgets and utilities for PyQt applications"),
+     'required_version': SUPERQT_REQVER},
     {'modname': 'textdistance',
      'package_name': "textdistance",
      'features': _('Compute distances between strings'),
@@ -259,6 +284,10 @@ DESCRIPTIONS = [
      'package_name': "watchdog",
      'features': _("Watch file changes on project directories"),
      'required_version': WATCHDOG_REQVER},
+     {'modname': "yarl",
+     'package_name': "yarl",
+     'features': _("URL parsing and changing"),
+     'required_version': YARL_REQVER},
 ]
 
 
@@ -345,6 +374,9 @@ class Dependency(object):
 
     def check(self):
         """Check if dependency is installed"""
+        if self.modname == 'spyder_kernels':
+            # TODO: Remove when spyder-kernels 3 is released!
+            return True
         if self.required_version:
             installed = programs.is_module_installed(
                 self.modname,
